summaryrefslogtreecommitdiffstats
path: root/config.def.h
diff options
context:
space:
mode:
Diffstat (limited to 'config.def.h')
-rw-r--r--config.def.h17
1 files changed, 12 insertions, 5 deletions
diff --git a/config.def.h b/config.def.h
index dd36224..f455111 100644
--- a/config.def.h
+++ b/config.def.h
@@ -6,11 +6,18 @@ enum {
WIN_HEIGHT = 600
};
-/* default color for window background: */
-static const char * const BG_COLOR = "#777777";
-/* default color for thumbnail selection: */
-static const char * const SEL_COLOR = "#DDDDDD";
-/* (see X(7) section "COLOR NAMES" for valid values) */
+/* bar font:
+ * (see X(7) section "FONT NAMES" for valid values)
+ */
+static const char * const BAR_FONT = "6x13";
+
+/* colors:
+ * (see X(7) section "COLOR NAMES" for valid values)
+ */
+static const char * const WIN_BG_COLOR = "#777777";
+static const char * const SEL_COLOR = "#DDDDDD";
+static const char * const BAR_BG_COLOR = "#222222";
+static const char * const BAR_FG_COLOR = "#EEEEEE";
#endif
#ifdef _IMAGE_CONFIG